/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：医生医疗资质信息表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.domain;

import java.io.Serializable;

import com.xwd.hospital.server.rest.res.ApiCode;
import lombok.*;
import java.util.List;

import com.baomidou.mybatisplus.annotation.*;

import io.swagger.v3.oas.annotations.media.Schema;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonProperty;

import com.xwd.hospital.server.base.BaseDomain;
import com.xwd.hospital.server.enums.DoctorTitleEnum;
import com.xwd.hospital.server.enums.AuditStateEnum;
import com.xwd.hospital.server.domain.DoctorInfo;
import com.xwd.hospital.server.domain.HospitalInfo;
import com.xwd.hospital.server.domain.DepartmentInfo;

@Data
@Builder(builderMethodName = "newBuilder")
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@TableName("`pms_medical_qualifications`")
@Schema(name = "MedicalQualifications", description = "医生医疗资质信息表")
public class MedicalQualifications extends BaseDomain {
    /**
     * Id
     */
    @TableId(value = "id", type = IdType.AUTO)
    @Schema(description = "Id", nullable = false)
    private Long id;
    /**
     * 医生Id
     */
    @TableField(value = "doctor_id")
    @Schema(description = "医生Id", nullable = false)
    private Long doctorId;
    /**
     * 医生Id
     */
    @Schema(description = "医生Id")
    @TableField(exist = false)
    private DoctorInfo doctor;
    /**
     * 医院Id
     */
    @TableField(value = "hospital_id")
    @Schema(description = "医院Id", nullable = false)
    private Long hospitalId;
    /**
     * 医院Id
     */
    @Schema(description = "医院Id")
    @TableField(exist = false)
    private HospitalInfo hospital;
    /**
     * 科室Id
     */
    @TableField(value = "department_id")
    @Schema(description = "科室Id", nullable = false)
    private Long departmentId;
    /**
     * 科室Id
     */
    @Schema(description = "科室Id")
    @TableField(exist = false)
    private DepartmentInfo department;
    /**
     * 职称
     */
    @TableField(value = "title")
    @Schema(description = "职称", nullable = false)
    private DoctorTitleEnum title;
    /**
     * 审核状态
     */
    @TableField(value = "audit_state")
    @Schema(description = "审核状态", nullable = false)
    private AuditStateEnum auditState;
    /**
     * 医疗资格证件图片
     */
    @TableField(value = "certificate_picture")
    @Schema(description = "医疗资格证件图片", nullable = false)
    private String certificatePicture;
    /**
     * 操作人Id
     */
    @TableField(value = "editor_id")
    @Schema(description = "操作人Id", nullable = false)
    private Long editorId;
    /**
     * 操作人
     */
    @TableField(value = "editor_name")
    @Schema(description = "操作人", nullable = false)
    private String editorName;
    /**
     * 创建时间
     */
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间", nullable = false)
    private java.util.Date createTime;
    /**
     * 更新时间
     */
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间", nullable = false)
    private java.util.Date updateTime;

    /**
     * 设置默认值
     */
    @Override
    public MedicalQualifications setDefault() {
        if (this.getTitle() == null) {
            this.setTitle(DoctorTitleEnum.RESIDENT_DOCTOR);
        }
        if (this.getAuditState() == null) {
            this.setAuditState(AuditStateEnum.TO_AUDIT);
        }
        if (this.getEditorId() == null) {
            this.setEditorId(1L);
        }
        if (this.getEditorName() == null) {
            this.setEditorName("admin");
        }
        if (this.getCreateTime() == null) {
            this.setCreateTime(new java.util.Date());
        }
        if (this.getUpdateTime() == null) {
            this.setUpdateTime(new java.util.Date());
        }
        return this;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate(boolean throwException) {
        if (this.getDoctorId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "医生Id不能为空！");
            }
            return false;
        }
        if (this.getHospitalId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "医院Id不能为空！");
            }
            return false;
        }
        if (this.getDepartmentId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "科室Id不能为空！");
            }
            return false;
        }
        if (this.getTitle() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "职称不能为空！");
            }
            return false;
        }
        if (this.getAuditState() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "审核状态不能为空！");
            }
            return false;
        }
        if (this.getCertificatePicture() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "医疗资格证件图片不能为空！");
            }
            return false;
        }
        if (this.getEditorId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人Id不能为空！");
            }
            return false;
        }
        if (this.getEditorName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人不能为空！");
            }
            return false;
        }
        return true;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate() {
        return this.validate(false);
    }

}
